@@ -1,13 +1,14 @@
 import typing as t
 from types import ModuleType
-from pydantic import BaseModel
+from pydantic import BaseModel, ValidationError
 
 if t.TYPE_CHECKING:
     from pipelime.piper.model import PipelimeCommand
+    from pipelime.stages import SampleStage
 
 
 class ActionInfo(BaseModel):
-    action: t.Union[t.Type, t.Callable]
+    action: t.Callable
     name: str
     description: str
     classpath: str
@@ -248,6 +249,10 @@ class PipelimeSymbolsHelper:
             return (("Imported Stage", "Imported Stages"), sym_cls)
         return sym_cls
 
+    @classmethod
+    def get_action(cls, action_name: str):
+        return PipelimeSymbolsHelper.get_actions().get(action_name, None)
+
     @classmethod
     def show_error_and_help(
         cls, name: str, should_be_cmd: bool, should_be_op: bool, should_be_stage: bool
@@ -328,9 +333,13 @@ def _unwrap_generic_type(symbol, verbose: bool):
 def print_command_op_stage_info(
     command_operator_stage: str, show_description: bool = True, recursive: bool = True
 ):
-    """
-    Prints detailed info about a pipelime command, a sequence operator or a sample
+    """Prints detailed info about a pipelime command, a sequence operator or a sample
     stage.
+
+    Args:
+      command_operator_stage: str:
+      show_description: bool:  (Default value = True)
+      recursive: bool:  (Default value = True)
     """
     from pipelime.cli.pretty_print import print_info
     from pipelime.choixe.utils.imports import import_symbol
@@ -462,6 +471,7 @@ def print_commands_ops_stages_list(
     recursive: bool = True,
 ):
     """Print a list of all available sequence operators and pipelime commands."""
+
     from pipelime.cli.pretty_print import (
         get_model_classpath,
         print_info,
@@ -515,21 +525,33 @@ def print_commands_ops_stages_list(
 
 
 def print_commands_list(show_details: bool = False):
-    """Print a list of all available pipelime commands."""
+    """Print a list of all available pipelime commands.
+
+    Args:
+      show_details: bool:  (Default value = False)
+    """
     print_commands_ops_stages_list(
         show_details=show_details, show_cmds=True, show_ops=False, show_stages=False
     )
 
 
 def print_sequence_operators_list(show_details: bool = False):
-    """Print a list of all available sequence operators."""
+    """Print a list of all available sequence operators.
+
+    Args:
+      show_details: bool:  (Default value = False)
+    """
     print_commands_ops_stages_list(
         show_details=show_details, show_cmds=False, show_ops=True, show_stages=False
     )
 
 
 def print_sample_stages_list(show_details: bool = False):
-    """Print a list of all available sample stages."""
+    """Print a list of all available sample stages.
+
+    Args:
+      show_details: bool:  (Default value = False)
+    """
     print_commands_ops_stages_list(
         show_details=show_details, show_cmds=False, show_ops=False, show_stages=True
     )
@@ -542,7 +564,15 @@ def pl_print(
     file: t.Optional[t.IO[str]] = None,
     flush: bool = False,
 ):
-    """Prints Items, Samples, Sequences, commands, stages, operations..."""
+    """Prints Items, Samples, Sequences, commands, stages, operations...
+
+    Args:
+      *objects: t.Any:
+      sep: str:  (Default value = " ")
+      end: str:  (Default value = "\n")
+      file: t.Optional[t.IO[str]]:  (Default value = None)
+      flush: bool:  (Default value = False)
+    """
     import inspect
     from rich import print as rprint
     from pydantic import BaseModel
@@ -575,13 +605,18 @@ def create_stage_from_config(
 ) -> "SampleStage":  # type: ignore # noqa: E602,F821
     """Creates a stage from a name and arguments.
 
-    :param stage_name: the name of the stage, eg, `compose`, `remap`, etc.
-    :type stage_name: str
-    :param stage_args: a mapping of the stage init arguments.
-    :type stage_args: t.Mapping[str, t.Any]]
-    :return: the stage object
-    :rtype: SampleStage
+    Args:
+        stage_name (str): the name of the stage, eg, `compose`, `remap`, etc.
+        stage_args (t.Union[t.Mapping[str, t.Any], t.Sequence, None]): a mapping of the
+            stage init arguments.
+
+    Raises:
+        ValueError: If the stage name is not a valid stage.
+
+    Returns:
+        SampleStage: The stage instance.
     """
+
     from pipelime.cli.utils import PipelimeSymbolsHelper
     from pipelime.stages import SampleStage
 
@@ -609,7 +644,7 @@ def create_stage_from_config(
         )
     except TypeError:
         # try to call without expanding args
-        return stage_cls(stage_args)
+        return stage_cls(stage_args)  # type: ignore
 
 
 def get_pipelime_command_cls(
@@ -650,3 +685,20 @@ def time_to_str(nanosec: int) -> str:
         nanosec -= microsec * 1000
         return f"{millisec}ms {microsec}us {nanosec}ns"
     return str(timedelta(microseconds=nanosec / 1000))
+
+
+def show_field_alias_valerr(e: ValidationError):
+    def _replace_alias(val):
+        if isinstance(val, str):
+            for field in e.model.__fields__.values():  # type: ignore
+                if (
+                    field.model_config.allow_population_by_field_name
+                    and field.has_alias
+                    and field.alias == val
+                ):
+                    return f"{field.name} / {field.alias}"
+        return val
+
+    for err in e.errors():
+        if "loc" in err:
+            err["loc"] = tuple(_replace_alias(l) for l in err["loc"])
