@@ -9,6 +9,7 @@ from pipelime.commands.general import (
     ValidateCommand,
     MapCommand,
     SortCommand,
+    FilterCommand,
 )
 from pipelime.commands.shell import ShellCommand
 from pipelime.commands.split_ops import (
@@ -17,4 +18,4 @@ from pipelime.commands.split_ops import (
     SplitCommand,
 )
 from pipelime.commands.toy_dataset import ToyDatasetCommand
-from pipelime.commands.piper import RunCommand, DrawCommand
+from pipelime.commands.piper import RunCommand, DrawCommand, WatchCommand
